==> haskell-binary-orphans-1.0.5-109.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-orphans
version:              1.0.5
visibility:           public
id:                   binary-orphans-1.0.5-1VCGcurzJlr6bEl6Wn9GAU
key:                  binary-orphans-1.0.5-1VCGcurzJlr6bEl6Wn9GAU
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Compatibility package for binary; provides instances
description:
    This package provides instances defined in later versions of @binary@ package

    Prior version 1 this packages provided instances for other packages.
    That functionality is moved to [binary-instances](https://hackage.haskell.org/package/binary-instances) package.

category:             Data, Binary, Parsing, Compatibility
abi:                  56e66dbd0a9596b1e0b8f48aebb65caa
exposed:              True
exposed-modules:      Data.Binary.Orphans
import-dirs:          /usr/lib/ghc-9.6.6/site-local/binary-orphans-1.0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/binary-orphans-1.0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/binary-orphans-1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-orphans
hs-libraries:         HSbinary-orphans-1.0.5-1VCGcurzJlr6bEl6Wn9GAU
depends:              base-4.18.2.1 binary-0.8.9.1
haddock-interfaces:
    /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock

haddock-html:         /usr/share/doc/haskell-binary-orphans/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-orphans-1.0.5-110-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-orphans
version:              1.0.5
visibility:           public
id:                   binary-orphans-1.0.5-2QdNlgpLYWR3AHIOi4WILQ
key:                  binary-orphans-1.0.5-2QdNlgpLYWR3AHIOi4WILQ
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Compatibility package for binary; provides instances
description:
    This package provides instances defined in later versions of @binary@ package

    Prior version 1 this packages provided instances for other packages.
    That functionality is moved to [binary-instances](https://hackage.haskell.org/package/binary-instances) package.

category:             Data, Binary, Parsing, Compatibility
abi:                  2ea253683eb632709d3fb8f530d54ac3
exposed:              True
exposed-modules:      Data.Binary.Orphans
import-dirs:          /usr/lib/ghc-9.6.6/site-local/binary-orphans-1.0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/binary-orphans-1.0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/binary-orphans-1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-orphans
hs-libraries:         HSbinary-orphans-1.0.5-2QdNlgpLYWR3AHIOi4WILQ
depends:              base-4.18.2.1 binary-0.8.9.1
haddock-interfaces:
    /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock

haddock-html:         /usr/share/doc/haskell-binary-orphans/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
